# thermal

[![pypi](https://img.shields.io/pypi/v/thermal.svg)](https://pypi.org/project/thermal/)
[![python](https://img.shields.io/pypi/pyversions/thermal.svg)](https://pypi.org/project/thermal/)
[![Build Status](https://github.com/sitmo/thermal/actions/workflows/dev.yml/badge.svg)](https://github.com/sitmo/thermal/actions/workflows/dev.yml)
[![codecov](https://codecov.io/gh/sitmo/thermal/branch/main/graphs/badge.svg)](https://codecov.io/github/sitmo/thermal)

Model Free surrogate time series generation.





* Documentation: <https://sitmo.github.io/thermal>
* GitHub: <https://github.com/sitmo/thermal>
* PyPI: <https://pypi.org/project/thermal/>
* Free software: MIT


## Features

* TODO
